@@ -13,7 +13,7 @@ import termios
 import time
 from contextlib import contextmanager
 
-__version__ = 'cplay-ng 5.1.0'
+__version__ = 'cplay-ng 5.2.0'
 
 AUDIO_EXTENSIONS = [
     'mp3', 'ogg', 'oga', 'opus', 'flac', 'm4a', 'm4b', 'wav', 'mid', 'wma'
@@ -78,12 +78,6 @@ def str_match(query, s):
     return all(q in s.lower() for q in query.lower().split())
 
 
-def set_volume(vol):
-    subprocess.check_call([
-        'pactl', 'set-sink-volume', '@DEFAULT_SINK@', '%i%%' % int(vol * 100)
-    ])
-
-
 def resize(*args):
     os.write(app.resize_out, b'.')
 
@@ -148,7 +142,9 @@ class Player:
         self._playing = 0
         self._buffer = b''
 
-        self.socket_path = '/tmp/mpv-cplay-%i.sock' % os.getpid()
+        self.socket_path = '%s/mpv-cplay-%i.sock' % (
+            os.getenv('XDG_RUNTIME_DIR', '/tmp'), os.getpid()
+        )
         self._proc = subprocess.Popen(
             [
                 'mpv',
@@ -189,7 +185,7 @@ class Player:
         msgs = self._buffer.split(b'\n')
         self._buffer = msgs.pop()
         for msg in msgs:
-            data = json.loads(msg.decode('utf-8'))
+            data = json.loads(msg.decode('utf-8', errors='replace'))
             self.handle_ipc(data)
 
     def get_progress(self):
@@ -203,6 +199,9 @@ class Player:
             title = '{} [{}]'.format(title, self.metadata['icy-title'])
         return title
 
+    def set_volume(self, vol):
+        self._ipc('set', 'volume', str(vol))
+
     def stop(self):
         self.is_playing = False
         self._ipc('stop')
@@ -759,7 +758,7 @@ class Application:
         elif self.tab.process_key(key):
             pass
         elif key in ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']:
-            set_volume(int(key, 10) / 9.0)
+            player.set_volume(int(key, 10) * 11)
         elif key == curses.KEY_RIGHT:
             player.seek(1)
         elif key == curses.KEY_LEFT:
